@@ -1,5 +1,16 @@
+my_traceback <- function(x = NULL) {
+    if(is.null(x) && !is.null(x <- get0(".Traceback", envir = baseenv())))
+    {}
+    else if (is.numeric(x)){
+      my_internal <- get0(".Internal", envir = baseenv())
+      x <- my_internal(traceback(x))
+    }
+      
+    x
+  }
+
 crumb <- function() {
-  x <- .traceback(1)
+  x <- my_traceback(1)
 
   if (any(grepl("^rmarkdown", x[[length(x)]]))) {
     srloc <- gsub('^(.*?)\\(|\\,(.*?)$|["]', "", x[[length(x)]][1])
